@@ -6,9 +6,9 @@ Type annotations for finspace service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_finspace.literals import EnvironmentStatus
+    from mypy_boto3_finspace.literals import EnvironmentStatusType
 
-    data: EnvironmentStatus = "CREATE_REQUESTED"
+    data: EnvironmentStatusType = "CREATE_REQUESTED"
     ```
 """
 import sys
@@ -19,10 +19,10 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("EnvironmentStatus", "FederationMode")
+__all__ = ("EnvironmentStatusType", "FederationModeType")
 
 
-EnvironmentStatus = Literal[
+EnvironmentStatusType = Literal[
     "CREATED",
     "CREATE_REQUESTED",
     "CREATING",
@@ -34,4 +34,4 @@ EnvironmentStatus = Literal[
     "RETRY_DELETION",
     "SUSPENDED",
 ]
-FederationMode = Literal["FEDERATED", "LOCAL"]
+FederationModeType = Literal["FEDERATED", "LOCAL"]
